==> pnp4nagios_0.6.13.orig.tar.gz: pnp4nagios-0.6.13/share/pnp/application/i18n/ru_RU/common.php <==
<?php defined('SYSPATH') OR die('No direct access allowed.');
$lang = array
(
    'datasource' => 'Источник данных: %s',
    'host' => 'Хост: %s',
    'service' => 'Служба: %s',
    'page' => 'Страница: %s',
    'page-basket' => 'Страница: Мой набор',
    'zoom-header' => 'Детализация',
    'status-box-header' => 'Статус',
    'multisite-box-header' => 'Multisite links',
    'search-box-header' => 'Поиск',
    'icon-box-header' => 'Действия',
    'basket-box-header' => 'Мой набор',
    'timerange-box-header' => 'Интервалы времени',
    'service-box-header' => 'Службы',
    'special-templates-box-header' => 'Специальные шаблоны',
    'pages-box-header' => 'Страницы',
    'nagios-summary-link-title' => 'Последние алерты за данный промежуток',
    'nagios-avail-link-title'   => 'Сводка доступности за данный промежуток',
    'timerange-selector-legend' => 'Выберите промежуток',
    'timerange-selector-title'  => 'Установка собственного интервала времени',
    'timerange-selector-submit-button' => 'ввести',
    'timerange-selector-clear-button'  => 'очистить',
    'timerange-selector-link'          => 'Собственный интервал',
    'start' => 'Начало',
    'end' => 'Окончание',
    'service-details' => 'Подробности о службе',
    'service-overview' => 'Обзор служб для "%s"',
    'title-pages-link' => 'Обзор страниц',
    'title-pdf-link' => 'Просмотр PDF',
    'title-xml-link' => 'Просмотр XML',
    'title-statistics-link' => 'Просмотр внутренней статистики PNP',
    'title-calendar-link' => 'Установка собственного временного интервала',
    'title-special-templates-link' => 'Просмотр специальных шаблонов',
    'title-docs-link' => 'Просмотреть документацию',
    'title-home-link' => 'Просмотр графиков',
    'docs-home' => 'На главную',
    'docs-box-header' => 'Меню',
    'docs-header' => 'Версия документации %s',
);

==> pnp4nagios_0.6.16.orig.tar.gz: pnp4nagios-0.6.16/share/pnp/application/i18n/ru_RU/common.php <==
<?php defined('SYSPATH') OR die('No direct access allowed.');
$lang = array
(
    'datasource' => 'Источник данных: %s',
    'host' => 'Хост: %s',
    'service' => 'Служба: %s',
    'page' => 'Страница: %s',
    'page-basket' => 'Страница: Мой набор',
    'zoom-header' => 'Детализация',
    'status-box-header' => 'Статус',
    'multisite-box-header' => 'Multisite links',
    'search-box-header' => 'Поиск',
    'icon-box-header' => 'Действия',
    'basket-box-header' => 'Мой набор',
    'timerange-box-header' => 'Интервалы времени',
    'service-box-header' => 'Службы',
    'special-templates-box-header' => 'Специальные шаблоны',
    'pages-box-header' => 'Страницы',
    'nagios-summary-link-title' => 'Последние алерты за данный промежуток',
    'nagios-avail-link-title'   => 'Сводка доступности за данный промежуток',
    'timerange-selector-legend' => 'Выберите промежуток',
    'timerange-selector-title'  => 'Установка собственного интервала времени',
    'timerange-selector-submit-button' => 'ввести',
    'timerange-selector-clear-button'  => 'очистить',
    'timerange-selector-link'          => 'Собственный интервал',
    'timerange-selector-overview'      => 'Overview',
    'start' => 'Начало',
    'end' => 'Окончание',
    'service-details' => 'Подробности о службе',
    'service-overview' => 'Обзор служб для "%s"',
    'title-pages-link' => 'Обзор страниц',
    'title-pdf-link' => 'Просмотр PDF',
    'title-xml-link' => 'Просмотр XML',
    'title-statistics-link' => 'Просмотр внутренней статистики PNP',
    'title-calendar-link' => 'Установка собственного временного интервала',
    'title-special-templates-link' => 'Просмотр специальных шаблонов',
    'title-docs-link' => 'Просмотреть документацию',
    'title-home-link' => 'Просмотр графиков',
    'docs-home' => 'На главную',
    'docs-box-header' => 'Меню',
    'docs-header' => 'Версия документации %s',
    'back' => 'назад',
    'mobile-all-hosts' => 'Все хосты',
    'mobile-search-hosts' => 'Поиск хостов',
    'mobile-pages' => 'Просмотр страниц',
    'mobile-special-templates' => 'Просмотр специальных шаблонов',
    'mobile-statistics' => 'Просмотр внутренней статистики',
    'mobile-go-classic' => 'Классический UI',
    'mobile-submit' => 'Ввести',
    'basket-empty' => 'Корзина пуста',
    'basket-show' => 'Показать корзину',
    'basket-clear' => 'Clear basket',
    'basket-remove' => 'Убрать %s',
    'basket-add-item' => 'Добавить этот элемент в мою корзину',
    'basket-add-service' => 'Добавить эту службу в мою корзину',
);
